@@ -24,8 +24,11 @@
 
 #define STRICT_R_HEADERS
 
+#include <stdlib.h>
+
 #include <R.h>
 #include <Rinternals.h>
+#include <R_ext/Rdynload.h>
 #include <R_ext/Print.h>
 
 #include "gensvm_print.h"
